package MFColor;
use strict;
use warnings;

use rlib "./";

use MFValue;
use base qw(MFValue);

use SFColor;
our $SField = new SFColor;

1;
__END__
